nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Ctrl0

Struct Ctrl0 

#[repr(transparent)]
pub struct Ctrl0(pub u32);
Contains the offsets of AB and CD in the RAM.

Tuple Fields

0: u32

Implementations

Source

impl Ctrl0

pub const fn abbpair(&self) -> Abbpair

Which bank-pair the offset ABOFF is within. This must be 0 if only 2-up

pub const fn set_abbpair(&mut self, val: Abbpair)

Which bank-pair the offset ABOFF is within. This must be 0 if only 2-up

pub const fn aboff(&self) -> u16

Word or DWord Offset of AB values, with B at [2]=0 and A at [2]=1 as far as the code sees (normally will be an interleaved bank so only sequential to AHB). Word offset only allowed if 32 bit operation. Ideally not in the same RAM as the CD values if 4-up

pub const fn set_aboff(&mut self, val: u16)

Word or DWord Offset of AB values, with B at [2]=0 and A at [2]=1 as far as the code sees (normally will be an interleaved bank so only sequential to AHB). Word offset only allowed if 32 bit operation. Ideally not in the same RAM as the CD values if 4-up

pub const fn cdbpair(&self) -> Cdbpair

Which bank-pair the offset CDOFF is within. This must be 0 if only 2-up

pub const fn set_cdbpair(&mut self, val: Cdbpair)

Which bank-pair the offset CDOFF is within. This must be 0 if only 2-up

pub const fn cdoff(&self) -> u16

Word or DWord Offset of CD, with D at [2]=0 and C at [2]=1 as far as the code sees (normally will be an interleaved bank so only sequential to AHB). Word offset only allowed if 32 bit operation. Ideally not in the same RAM as the AB values

pub const fn set_cdoff(&mut self, val: u16)

Word or DWord Offset of CD, with D at [2]=0 and C at [2]=1 as far as the code sees (normally will be an interleaved bank so only sequential to AHB). Word offset only allowed if 32 bit operation. Ideally not in the same RAM as the AB values