nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Ctrl1

Struct Ctrl1 

#[repr(transparent)]
pub struct Ctrl1(pub u32);
Contains the opcode mode, iteration count, and result offset (in RAM) and also launches the accelerator. Note: with CP version: CTRL0 and CRTL1 can be written in one go with MCRR.

Tuple Fields

0: u32

Implementations

Source

impl Ctrl1

pub const fn iter(&self) -> u8

Iteration counter. Is number_cycles - 1. write 0 means Does one cycle - does not iterate.

pub const fn set_iter(&mut self, val: u8)

Iteration counter. Is number_cycles - 1. write 0 means Does one cycle - does not iterate.

pub const fn mode(&self) -> u8

Operation mode to perform. write 0 means Accelerator is inactive. write others means accelerator is active.

pub const fn set_mode(&mut self, val: u8)

Operation mode to perform. write 0 means Accelerator is inactive. write others means accelerator is active.

pub const fn resbpair(&self) -> Resbpair

Which bank-pair the offset RESOFF is within. This must be 0 if only 2-up. Ideally this is not the same bank as ABBPAIR (when 4-up supported)

pub const fn set_resbpair(&mut self, val: Resbpair)

Which bank-pair the offset RESOFF is within. This must be 0 if only 2-up. Ideally this is not the same bank as ABBPAIR (when 4-up supported)

pub const fn resoff(&self) -> u16

Word or DWord Offset of result. Word offset only allowed if 32 bit operation. Ideally not in the same RAM as the AB and CD values

pub const fn set_resoff(&mut self, val: u16)

Word or DWord Offset of result. Word offset only allowed if 32 bit operation. Ideally not in the same RAM as the AB and CD values

pub const fn cskip(&self) -> Cskip

Skip rules on Carry if needed. This operation will be skipped based on Carry value (from previous operation) if not 0:

pub const fn set_cskip(&mut self, val: Cskip)

Skip rules on Carry if needed. This operation will be skipped based on Carry value (from previous operation) if not 0: