nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Dreg

Struct Dreg 

#[repr(transparent)]
pub struct Dreg(pub u32);
D register

Tuple Fields

0: u32

Implementations

Source

impl Dreg

pub const fn reg_value(&self) -> u32

Register to be fed into Multiplier. Is not normally written or read by application, but is available when accelerator not busy.

pub const fn set_reg_value(&mut self, val: u32)

Register to be fed into Multiplier. Is not normally written or read by application, but is available when accelerator not busy.