nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Res2

Struct Res2 

#[repr(transparent)]
pub struct Res2(pub u32);
Result register 2

Tuple Fields

0: u32

Implementations

Source

impl Res2

pub const fn reg_value(&self) -> u32

Register to hold working result (from multiplier, adder/xor, etc). Is not normally written or read by application, but is available when accelerator not busy.

pub const fn set_reg_value(&mut self, val: u32)

Register to hold working result (from multiplier, adder/xor, etc). Is not normally written or read by application, but is available when accelerator not busy.